Bibliography
============

.. [BK08] C. Baier and J.-P. Katoen. *Principles of Model Checking*. MIT Press, 2008.

.. [BJPPS12] R. Bloem, B. Jobstmann, N. Piterman, A. Pnueli, and Y. Sa'ar (2012). `Synthesis of Reactive(1) designs <http://dx.doi.org/10.1016/j.jcss.2011.08.007>`_. *Journal of Computer and System Sciences*, 78:911--938

.. [LS11] E.A. Lee and S.A. Seshia. *Introduction to Embedded Systems - A Cyber-Physical Systems Approach*. `LeeSeshia.org <http://LeeSeshia.org>`_, 2011.

.. [S12] N. Spooner (2012). `Evaluation and Benchmarking for Robot Motion Planning Problems Using TuLiP <http://resolver.caltech.edu/CaltechCDSTR:2012.007>`_. Caltech SURF Final Report.

.. [W10] T. Wongpiromsarn (2010). `Formal Methods for Design and Verification of Embedded Control Systems: Application to an Autonomous Vehicle <http://resolver.caltech.edu/CaltechTHESIS:05272010-153304667>`_. PhD thesis. California Institute of Technology.

.. [WTM12] T. Wongpiromsarn, U. Topcu, and R. Murray (2012). `Receding horizon temporal logic planning <http://dx.doi.org/10.1109/TAC.2012.2195811>`_. *IEEE Transactions on Automatic Control*, 57(11):2817--2830.

.. [WTOXM11] T. Wongpiromsarn, U. Topcu, N. Ozay, H. Xu, and R. Murray (2011). `TuLiP: a software toolbox for receding horizon temporal logic planning <http://dx.doi.org/10.1145/1967701.1967747>`_. In *Proc. of Hybrid Systems: Computation and Control (HSCC)*.
